@@ -17,6 +17,8 @@ def load():
     file_pro.load(total=450)
     file_pro.change_freq('weekly')
     file_pro.load(total=60)
+    file_pro.change_freq('monthly')
+    file_pro.load(total=12)
 
     file_pro.change_data_type('kline')
     file_pro.change_timeframe('1m')
@@ -27,4 +29,3 @@ def load():
 
 
 load()
-
